# fakefile
Create fake files

### Installation
```
pip install fakefile
```

### Usage
To use fakefile, simply call the program from command prompt with a filename and required size in KiB.
```
fakefile [-h] [filename] [size]
```

#### Example
```
fakefile assignment.pdf 250
```
